@@ -5,13 +5,13 @@
 
 set -e
 
-VERSION="9.1.0"
+VERSION="9.13.0"
 MAJOR="9"
 
 # For idempotency, remove build data or built output first
 rm -rf ansible-build-data built
 
-pip3 install --user --upgrade antsibull
+pip3 install --user --upgrade "antsibull-build==0.69.0"
 git clone https://github.com/ansible-community/ansible-build-data.git
 mkdir -p built collection-cache
 BUILD_DATA_DIR="ansible-build-data/${MAJOR}"
